pub struct UpdateAnnouncementOptions {Show 14 fields
pub type: Option<AnnouncementType>,
pub enabled: Option<bool>,
pub enabled_start: Option<Option<DateTime<Utc>>>,
pub enabled_end: Option<Option<DateTime<Utc>>>,
pub dismissible: Option<bool>,
pub dismissible_end: Option<Option<DateTime<Utc>>>,
pub title: Option<CompactString>,
pub title_translations: Option<BTreeMap<CompactString, CompactString>>,
pub content: Option<CompactString>,
pub content_translations: Option<BTreeMap<CompactString, CompactString>>,
pub locations: Option<Vec<Uuid>>,
pub nodes: Option<Vec<Uuid>>,
pub backup_configurations: Option<Vec<Uuid>>,
pub eggs: Option<Vec<Uuid>>,
}Fields
type: Option<AnnouncementType>enabled: Option<bool>enabled_start: Option<Option<DateTime<Utc>>>enabled_end: Option<Option<DateTime<Utc>>>dismissible: Option<bool>dismissible_end: Option<Option<DateTime<Utc>>>title: Option<CompactString>title_translations: Option<BTreeMap<CompactString, CompactString>>content: Option<CompactString>content_translations: Option<BTreeMap<CompactString, CompactString>>locations: Option<Vec<Uuid>>nodes: Option<Vec<Uuid>>backup_configurations: Option<Vec<Uuid>>eggs: Option<Vec<Uuid>>Trait Implementations
Sourceimpl Clone for UpdateAnnouncementOptions
impl Clone for UpdateAnnouncementOptions
Sourcefn clone(&self) -> UpdateAnnouncementOptions
fn clone(&self) -> UpdateAnnouncementOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateAnnouncementOptions
impl ComposeSchema for UpdateAnnouncementOptions
Sourceimpl Default for UpdateAnnouncementOptions
impl Default for UpdateAnnouncementOptions
Sourcefn default() -> UpdateAnnouncementOptions
fn default() -> UpdateAnnouncementOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateAnnouncementOptions
impl<'de> Deserialize<'de> for UpdateAnnouncementOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for UpdateAnnouncementOptions
impl ToSchema for UpdateAnnouncementOptions
Sourceimpl Validate for UpdateAnnouncementOptions
impl Validate for UpdateAnnouncementOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateAnnouncementOptions
impl RefUnwindSafe for UpdateAnnouncementOptions
impl Send for UpdateAnnouncementOptions
impl Sync for UpdateAnnouncementOptions
impl Unpin for UpdateAnnouncementOptions
impl UnsafeUnpin for UpdateAnnouncementOptions
impl UnwindSafe for UpdateAnnouncementOptions